@@ -2,4 +2,4 @@ from __future__ import print_function, absolute_import
 
 from torchreid.reid.engine.image import ImageSoftmaxEngine, ImageTripletEngine
 from torchreid.reid.engine.video import VideoSoftmaxEngine, VideoTripletEngine
-from torchreid.reid.engine import Engine
+from torchreid.reid.engine.engine import Engine
