@@ -3,7 +3,7 @@ from __future__ import division, print_function, absolute_import
 from torchreid.reid import metrics
 from torchreid.reid.losses import TripletLoss, CrossEntropyLoss
 
-from torchreid.reid.engine import Engine
+from torchreid.reid.engine.engine import Engine
 
 
 class ImageTripletEngine(Engine):
